IconFont Demo

# 

- 
  店铺
  &#xe602;
- 
  自定义
  &#xe603;
- 
  模板
  &#xe604;
- 
  一键生成
  &#xe605;
- 
  轻松上架
  &#xe606;
- 
  我的客户
  &#xe607;
- 
  follower
  &#xe608;
- 
  qq
  &#xe609;
- 
  二维码
  &#xe60a;
- 
  分销
  &#xe60b;
- 
  服务
  &#xe60c;
- 
  供应商 (1)
  &#xe60d;
- 
  供应商
  &#xe60e;
- 
  合作
  &#xe60f;
- 
  秒杀
  &#xe610;
- 
  闹钟
  &#xe611;
- 
  品牌
  &#xe612;
- 
  评价
  &#xe613;
- 
  市场分析
  &#xe614;
- 
  收益 (1)
  &#xe615;
- 
  收益
  &#xe616;
- 
  数据
  &#xe617;
- 
  团队
  &#xe618;
- 
  团购
  &#xe619;
- 
  微信
  &#xe61a;
- 
  文书
  &#xe61b;
- 
  线路
  &#xe61c;
- 
  销量最高
  &#xe61d;
- 
  分销
  &#xe61e;
- 
  服务
  &#xe61f;
- 
  供应商 (1)
  &#xe620;
- 
  供应商
  &#xe621;
- 
  合作
  &#xe622;
- 
  秒杀
  &#xe623;
- 
  闹钟
  &#xe624;
- 
  品牌
  &#xe625;
- 
  评价
  &#xe626;
- 
  市场分析
  &#xe627;
- 
  收益 (1)
  &#xe628;
- 
  收益
  &#xe629;
- 
  评价
  &#xe62a;
- 
  市场分析
  &#xe62b;
- 
  收益 (1)
  &#xe62c;
- 
  收益
  &#xe62d;
- 
  数据
  &#xe62e;
- 
  团队
  &#xe62f;
- 
  团购
  &#xe630;
- 
  文书
  &#xe632;
- 
  线路
  &#xe633;
- 
  销量最高
  &#xe634;

## Unicode 引用

Unicode 是字体在网页端最原始的应用方式，特点是：

- 兼容性最好，支持 IE6+，及所有现代浏览器。
- 支持按字体的方式去动态调整图标大小，颜色等等。
- 但是因为是字体，所以不支持多色。只能使用平台里单色的图标，就算项目里有多色图标也会自动去色。

> 注意：新版 iconfont 支持多色图标，这些多色图标在 Unicode 模式下将不能使用，如果有需求建议使用symbol 的引用方式

Unicode 使用步骤如下：

### 第一步：拷贝项目下面生成的 `@font-face`

    @font-face {
      font-family: 'iconfont';
      src: url('iconfont.eot');
      src: url('iconfont.eot?#iefix') format('embedded-opentype'),
          url('iconfont.woff2') format('woff2'),
          url('iconfont.woff') format('woff'),
          url('iconfont.ttf') format('truetype'),
          url('iconfont.svg#iconfont') format('svg');
    }

### 第二步：定义使用 iconfont 的样式

    .iconfont {
      font-family: "iconfont" !important;
      font-size: 16px;
      font-style: normal;
      -webkit-font-smoothing: antialiased;
      -moz-osx-font-smoothing: grayscale;
    }

### 第三步：挑选相应图标并获取字体编码，应用于页面

    <span class="iconfont">&#x33;</span>

> "iconfont" 是你项目下的 font-family。可以通过编辑项目查看，默认是 "iconfont"。

- 店铺
  .icon-iconfonticonfontdianpu5
- 自定义
  .icon-iconfontcustomize
- 模板
  .icon-iconfontmoban
- 一键生成
  .icon-iconfontyijiantuiguang
- 轻松上架
  .icon-iconfontshangpinshangjia
- 我的客户
  .icon-iconfontkehu01
- follower
  .icon-follower
- qq
  .icon-qq
- 二维码
  .icon-erweima
- 分销
  .icon-fenxiao
- 服务
  .icon-fuwu
- 供应商 (1)
  .icon-gongyingshang1
- 供应商
  .icon-gongyingshang
- 合作
  .icon-hezuo
- 秒杀
  .icon-miaosha
- 闹钟
  .icon-naozhong
- 品牌
  .icon-pinpai
- 评价
  .icon-pingjia
- 市场分析
  .icon-shichangfenxi
- 收益 (1)
  .icon-shouyi1
- 收益
  .icon-shouyi
- 数据
  .icon-shuju
- 团队
  .icon-tuandui
- 团购
  .icon-tuangou
- 微信
  .icon-weixin
- 文书
  .icon-wenshu
- 线路
  .icon-xianlu
- 销量最高
  .icon-xiaoliangzuigao
- 分销
  .icon-fenxiao1
- 服务
  .icon-fuwu1
- 供应商 (1)
  .icon-gongyingshang11
- 供应商
  .icon-gongyingshang2
- 合作
  .icon-hezuo1
- 秒杀
  .icon-miaosha1
- 闹钟
  .icon-naozhong1
- 品牌
  .icon-pinpai1
- 评价
  .icon-pingjia1
- 市场分析
  .icon-shichangfenxi1
- 收益 (1)
  .icon-shouyi11
- 收益
  .icon-shouyi2
- 评价
  .icon-pingjia2
- 市场分析
  .icon-shichangfenxi2
- 收益 (1)
  .icon-shouyi12
- 收益
  .icon-shouyi3
- 数据
  .icon-shuju1
- 团队
  .icon-tuandui1
- 团购
  .icon-tuangou1
- 文书
  .icon-wenshu1
- 线路
  .icon-xianlu1
- 销量最高
  .icon-xiaoliangzuigao1

## font-class 引用

font-class 是 Unicode 使用方式的一种变种，主要是解决 Unicode 书写不直观，语意不明确的问题。

与 Unicode 使用方式相比，具有如下特点：

- 兼容性良好，支持 IE8+，及所有现代浏览器。
- 相比于 Unicode 语意明确，书写更直观。可以很容易分辨这个 icon 是什么。
- 因为使用 class 来定义图标，所以当要替换图标时，只需要修改 class 里面的 Unicode 引用。
- 不过因为本质上还是使用的字体，所以多色图标还是不支持的。

使用步骤如下：

### 第一步：引入项目下面生成的 fontclass 代码：

    <link rel="stylesheet" href="./iconfont.css">

### 第二步：挑选相应图标并获取类名，应用于页面：

    <span class="iconfont icon--xxx"></span>

> " iconfont" 是你项目下的 font-family。可以通过编辑项目查看，默认是 "iconfont"。

- 店铺
  #icon-iconfonticonfontdianpu5
- 自定义
  #icon-iconfontcustomize
- 模板
  #icon-iconfontmoban
- 一键生成
  #icon-iconfontyijiantuiguang
- 轻松上架
  #icon-iconfontshangpinshangjia
- 我的客户
  #icon-iconfontkehu01
- follower
  #icon-follower
- qq
  #icon-qq
- 二维码
  #icon-erweima
- 分销
  #icon-fenxiao
- 服务
  #icon-fuwu
- 供应商 (1)
  #icon-gongyingshang1
- 供应商
  #icon-gongyingshang
- 合作
  #icon-hezuo
- 秒杀
  #icon-miaosha
- 闹钟
  #icon-naozhong
- 品牌
  #icon-pinpai
- 评价
  #icon-pingjia
- 市场分析
  #icon-shichangfenxi
- 收益 (1)
  #icon-shouyi1
- 收益
  #icon-shouyi
- 数据
  #icon-shuju
- 团队
  #icon-tuandui
- 团购
  #icon-tuangou
- 微信
  #icon-weixin
- 文书
  #icon-wenshu
- 线路
  #icon-xianlu
- 销量最高
  #icon-xiaoliangzuigao
- 分销
  #icon-fenxiao1
- 服务
  #icon-fuwu1
- 供应商 (1)
  #icon-gongyingshang11
- 供应商
  #icon-gongyingshang2
- 合作
  #icon-hezuo1
- 秒杀
  #icon-miaosha1
- 闹钟
  #icon-naozhong1
- 品牌
  #icon-pinpai1
- 评价
  #icon-pingjia1
- 市场分析
  #icon-shichangfenxi1
- 收益 (1)
  #icon-shouyi11
- 收益
  #icon-shouyi2
- 评价
  #icon-pingjia2
- 市场分析
  #icon-shichangfenxi2
- 收益 (1)
  #icon-shouyi12
- 收益
  #icon-shouyi3
- 数据
  #icon-shuju1
- 团队
  #icon-tuandui1
- 团购
  #icon-tuangou1
- 文书
  #icon-wenshu1
- 线路
  #icon-xianlu1
- 销量最高
  #icon-xiaoliangzuigao1

## Symbol 引用

这是一种全新的使用方式，应该说这才是未来的主流，也是平台目前推荐的用法。相关介绍可以参考这篇文章 这种用法其实是做了一个 SVG 的集合，与另外两种相比具有如下特点：

- 支持多色图标了，不再受单色限制。
- 通过一些技巧，支持像字体那样，通过 `font-size`, `color` 来调整样式。
- 兼容性较差，支持 IE9+，及现代浏览器。
- 浏览器渲染 SVG 的性能一般，还不如 png。

使用步骤如下：

### 第一步：引入项目下面生成的 symbol 代码：

    <script src="./iconfont.js"></script>

### 第二步：加入通用 CSS 代码（引入一次就行）：

    <style>
    .icon {
      width: 1em;
      height: 1em;
      vertical-align: -0.15em;
      fill: currentColor;
      overflow: hidden;
    }
    </style>

### 第三步：挑选相应图标并获取类名，应用于页面：

    <svg class="icon" aria-hidden="true">
      <use xlink:href="#icon-xxx"></use>
    </svg>